Routers
=======

Routing implementations for genro-asgi.

StaticRouter
------------

Filesystem-backed router for serving static files.

.. automodule:: genro_asgi.routers.static_router
   :members:
   :undoc-members:
   :show-inheritance:
